### Versions

|Date|Tag|What have been done|What going to change|
|-|-|-|-|
|2019-02-17|__v0.1__|Init the project||
|2019-03-10|__v0.2__|Support other domains||
|2019-05-20|__v0.3__|Support the new version of API||
|2020-04-10|__v0.4__|Add a function to download all pages||
|2020-04-13|__v0.5__|Add a function convert json to tsv||
|2020-05-14|__v0.6__|Fixed a bug in auth with different base url||
|2020-05-20|__v0.7__|Update page size for download all||
|2020-05-22|__v0.8__|rm line breaks in tsv export||
|2020-05-28|__v0.9__|updated column value to data||
|2020-10-07|__v0.10__|add function to check token||
|2021-06-09|__v0.11__|supoort MFA in auth||
|2022-01-18|__v0.12__|support python3||
|2022-02-22|__v1.0__|support pip package||
|2022-02-22|__v1.01__|updated images at README.md||
|2022-02-22|__v1.02__|updated readme links||
|2022-02-22|__v1.03__|support more objects||
|2022-02-22|__v1.04__|support more models||
